@@ -9,6 +9,7 @@ import txaio
 txaio.use_twisted()
 
 from ._version import __version__  # noqa
+from ._exception import InvalidConfigException  # noqa
 from .common import address, uint256, unpack_uint256, pack_uint256,\
     uint128, unpack_uint128, pack_uint128  # noqa
 from . import meta, mrealm, xbr, xbrmm, xbrnetwork  # noqa
@@ -31,4 +32,5 @@ __all__ = (
     'schema',
     'globalschema',
     'mrealmschema',
+    'InvalidConfigException',
 )
